# EDF API

## Description
Python API wrapper to retrieve Linky consumption data from your [EDF](https://www.edf.fr/) account.

Allows to retrieve consumption and prices data every 30min.
Information on electrical outages is also reported.

The pacakge is available on PyPI here: [edf-api](https://pypi.org/project/edf-api/)<br>
Documentation is available on [Read The Docs](https://edf-api.readthedocs.io/)
